==> nextcloud-14.0.13.zip: nextcloud/apps/files_sharing/l10n/gl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Compartido con outros",
    "Shared with you" : "Compartido con vostede",
    "Shared by link" : "Compartido por ligazón",
    "Deleted shares" : "Recursos compartidos eliminados",
    "Shares" : "Recursos compartidos",
    "Nothing shared with you yet" : "Aínda non hai nada compartido con vostede.",
    "Files and folders others share with you will show up here" : "Os ficheiros e cartafoles que outros compartan con vostede amosaranse aquí",
    "Nothing shared yet" : "Aínda non hai nada compartido",
    "Files and folders you share will show up here" : "Os ficheiros e cartafoles que comparta amosaranse aquí",
    "No shared links" : "Non hai ligazóns compartidas",
    "Files and folders you share by link will show up here" : "Os ficheiros e cartafoles que comparta por ligazón amosaranse aquí",
    "No deleted shares" : "Non hai recursos compartidos eliminados",
    "Shares you deleted will show up here" : "Os recursos compartidos eliminados amosaránse aquí",
    "No shares" : "Ningún recurso compartido",
    "Shares will show up here" : "Os recursos compartidos amosaránse aquí",
    "Restore share" : "Restaurar recursos compartido",
    "Something happened. Unable to restore the share." : "Algo aconteceu. Non é posíbel restaurar o recurso compartido",
    "Move or copy" : "Mover ou copiar",
    "Download" : "Descargar",
    "Delete" : "Eliminar",
    "You can upload into this folder" : "Pode envialo a este cartafol",
    "Terms of service" : "Termos do servizo",
    "No compatible server found at {remote}" : "Non se atopa un servidor compatíbel en {remote}",
    "Invalid server URL" : "URL de servidor incorrecto",
    "Failed to add the public link to your Nextcloud" : "Non foi posíbel engadir a ligazón pública ao seu Nextcloud",
    "No expiration date set" : "Non se definiu a data de caducidade",
    "Shared by" : "Compartido por",
    "File shares" : "Compartir ficheiros",
    "Downloaded via public link" : "Descargado mediante unha ligazón pública",
    "Downloaded by {email}" : "Descargado por {email}",
    "{file} downloaded via public link" : "{file} descargado mediante unha ligazón pública",
    "{email} downloaded {file}" : "{email} descargou {file}",
    "Shared with group {group}" : "Compartido co grupo {group}",
    "Removed share for group {group}" : "Retirar o recurso compartido para o grupo {group}",
    "{actor} shared with group {group}" : "{actor} compartiu co grupo {group}",
    "{actor} removed share for group {group}" : "{actor} retirou o recurso compartido para o grupo {group}",
    "You shared {file} with group {group}" : "Vostede compartiu {file} co grupo {group}",
    "You removed group {group} from {file}" : "Vostede retirou o grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} compartiu {file} co grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} retirou o grupo {group} de {file}",
    "Shared as public link" : "Compartido como ligazón pública",
    "Removed public link" : "Retirada a ligazón pública",
    "Public link expired" : "A ligazón pública caducou",
    "{actor} shared as public link" : "{actor} compartiu como ligazón pública",
    "{actor} removed public link" : "{actor} retirou a ligazón pública",
    "Public link of {actor} expired" : "A ligazón pública de {actor} caducou",
    "You shared {file} as public link" : "Vostede compartiu {file} como ligazón pública",
    "You removed public link for {file}" : "Vostede retirou a ligazón pública de {file}",
    "Public link expired for {file}" : "A ligazón pública para {file} caducou",
    "{actor} shared {file} as public link" : "{actor} compartiu {file} como ligazón pública",
    "{actor} removed public link for {file}" : "{actor} retirou a ligazón pública para {file}",
    "Public link of {actor} for {file} expired" : "A ligazón pública de {actor} para {file} caducou",
    "{user} accepted the remote share" : "{user} aceptou a compartición remota",
    "{user} declined the remote share" : "{user} declinou a compartición remota",
    "You received a new remote share {file} from {user}" : "Recibiu unha nova compartición remota {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceptou a compartición remotade {file}",
    "{user} declined the remote share of {file}" : "{user} declinou a compartición remota de {file}",
    "{user} unshared {file} from you" : "{user} deixou de compartir {file} con vostede",
    "Shared with {user}" : "Compartido con {user}",
    "Removed share for {user}" : "Retirar o compartido para {user}",
    "You removed yourself" : "Retirou a sí mesmo",
    "{actor} removed themselves" : "{actor} foi retirado",
    "{actor} shared with {user}" : "{actor} compartiu con {user}",
    "{actor} removed share for {user}" : "{actor} retirou o compartido para {user}",
    "Shared by {actor}" : "Compartido por {actor}",
    "{actor} removed share" : "{actor} retirou o compartido",
    "You shared {file} with {user}" : "Vostede compartiu {file} con  {user}",
    "You removed {user} from {file}" : "Vostede retirou a {user} de {file}",
    "You removed yourself from {file}" : "Vostede retirouse a sí mesmo de {file}",
    "{actor} removed themselves from {file}" : "{actor} foi retirado de {file}",
    "{actor} shared {file} with {user}" : "{actor} compartiu {file} con {user}",
    "{actor} removed {user} from {file}" : "{actor} retirou a {user} de {file}",
    "{actor} shared {file} with you" : "{actor} compartiu {file} con vostede",
    "{actor} removed you from the share named {file}" : "{actor} retirouno a vostede da compartición nomeada {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Foi <strong>descargado</strong> un ficheiro ou cartafol compartido por correo ou ligazón pública",
    "A file or folder was shared from <strong>another server</strong>" : "Compartiuse un ficheiro ou cartafol dende <strong>outro servidor</strong>",
    "A file or folder has been <strong>shared</strong>" : "<strong>Compartiuse</strong> un ficheiro ou cartafol",
    "Wrong share ID, share doesn't exist" : "O ID do recurso compartido non é correcto, o recurso compartido non existe",
    "could not delete share" : "non foi posíbel eliminar o recurso compartido",
    "Could not delete share" : "Non foi posíbel eliminar o recurso compartido",
    "Please specify a file or folder path" : "Especifique a ruta dun ficheiro ou cartafol",
    "Wrong path, file/folder doesn't exist" : "Ruta incorrecta, o ficheiro/cartafol non existe",
    "Could not create share" : "Non foi posíbel crear o recurso compartido",
    "invalid permissions" : "permisos incorrectos",
    "Please specify a valid user" : "Especifique un usuario correcto",
    "Group sharing is disabled by the administrator" : "A opción de compartir en grupo foi desactivada polo administrador",
    "Please specify a valid group" : "Especifique un grupo correcto",
    "Public link sharing is disabled by the administrator" : "Compartir por ligazón pública foi desactivado polo administrador",
    "Public upload disabled by the administrator" : "O envío público foi desactivado polo administrador",
    "Public upload is only possible for publicly shared folders" : "O envío público só é posíbel para aos cartafoles públicos compartidos",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Compartir %s enviando o contrasinal por Nextcloud Talk fallou porque Nextcloud Talk non está activado",
    "Invalid date, date format must be YYYY-MM-DD" : "Data incorrecta, o formato da date debe ser AAAA-MM-DD",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Fallou a compartición de %1$s, xa que a infraestrutura non permite accións do tipo %2$s",
    "You cannot share to a Circle if the app is not enabled" : "Vostede non pode compartir para un Circulo se o aplicativo non esta activado",
    "Please specify a valid circle" : "Especifique un circulo correcto",
    "Sharing %s failed because the back end does not support room shares" : "Fallou a compartición de %s, xa que a infraestrutura non admite salas compartidas",
    "Unknown share type" : "Tipo descoñecido de recurso compartido",
    "Not a directory" : "Non é un directorio",
    "Could not lock path" : "Non foi posíbel bloquear a ruta",
    "Wrong or no update parameter given" : "Parámetro incorrecto ou non actualizado",
    "Can't change permissions for public share links" : "Non é posíbel cambiar os permisos das ligazóns de recursos compartidos públicos",
    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Compartir enviando o contrasinal por Nextcloud Talk fallou porque Nextcloud Talk non está activado",
    "shared by %s" : "compartido por %s",
    "Download all files" : "Descargar todos os ficheiros",
    "Direct link" : "Ligazón directa",
    "Add to your Nextcloud" : "Engadir ao seu Nextcloud",
    "Share API is disabled" : "A API de compartición foi desactivada",
    "File sharing" : "Compartición de ficheiros",
    "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "Este aplicativo permítelle aos usuarios compartir ficheiros dentro de Nextcloud. Se o activa, o administrador pode escoller que grupos poden compartir fiheiros. Os usuarios implicados poderán compartir ficheiros e cartafoles con outros usuarios e grupos dentro do Nextcloud. Ademais, se o administrador activa a característica de ligazón compartida, pode empregarse unha ligazón externa para compartir ficheiros con outros usuarios fora do Nextcloud. Os administradores poden obrigar a usar contrasinais ou datas de caducidade  e activar a compartición de servidor a servidor mediante ligazóns compartidas, así como compartir dende dispositivos móbiles.\nDesactivar esta característica elimina os ficheiros compartidos e os cartafoles no servidor, para todos los receptores, e tamén dos clientes de sincronización e móbiles. Ten dispoñíbel máis información na documentación do Nextcloud.",
    "Link to a file" : "Ligar a un ficheiro",
    "Shared" : "Compartido",
    "Share" : "Compartir",
    "Sharing" : "Compartindo",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Name" : "Nome",
    "Share time" : "Compartido hai",
    "Expiration date" : "Data de caducidade",
    "Sorry, this link doesn’t seem to work anymore." : "Semella que esta ligazón non funciona.",
    "Reasons might be:" : "As razóns poderían ser:",
    "the item was removed" : "o elemento foi retirado",
    "the link expired" : "a ligazón caducou",
    "sharing is disabled" : "foi desactivada a compartición",
    "For more info, please ask the person who sent this link." : "Para obter máis información, pregúntelle á persoa que lle enviou a ligazón.",
    "Share note" : "Compartir nota",
    "Toggle grid view" : "Alternar a vista de grella",
    "Download %s" : "Descargar %s",
    "Upload files to %s" : "Enviar ficheiros a %s",
    "Note" : "Nota",
    "Select or drop files" : "Seleccione ou arrastre e solte ficheiros",
    "Uploading files…" : "Enviando ficheiros…",
    "Uploaded files:" : "Ficheiros enviados:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Ao enviar ficheiros acepta os %1$s termos do servizo %2$s.",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Fallou a compartición de %s, xa que a infraestrutura non permite accións do tipo %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.0.zip: nextcloud/apps/files_sharing/l10n/gl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Compartido con outros",
    "Shared with you" : "Compartido con vostede",
    "Shared by link" : "Compartido por ligazón",
    "Nothing shared with you yet" : "Aínda non hai nada compartido con vostede.",
    "Files and folders others share with you will show up here" : "Os ficheiros e cartafoles que outros compartan con vostede amosaranse aquí",
    "Nothing shared yet" : "Aínda non hay nada compartido",
    "Files and folders you share will show up here" : "Os ficheiros e cartafoles que comparta amosaranse aquí",
    "No shared links" : "Non hai ligazóns compartidas",
    "Files and folders you share by link will show up here" : "Os ficheiros e cartafoles que comparta por ligazón amosaranse aquí",
    "Download" : "Descargar",
    "You can upload into this folder" : "Pode envialo a este cartafol",
    "No compatible server found at {remote}" : "Non se atopa un servidor compatíbel en {remote}",
    "Invalid server URL" : "URL de servidor incorrecto",
    "Failed to add the public link to your Nextcloud" : "Non foi posíbel engadir a ligazón pública ao seu Nextcloud",
    "Share" : "Compartir",
    "No expiration date set" : "Non se definiu a data de caducidade",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartindo",
    "File shares" : "Compartir ficheiros",
    "Downloaded via public link" : "Descargado mediante unha ligazón pública",
    "Downloaded by {email}" : "Descargado por {email}",
    "{file} downloaded via public link" : "{file} descargado mediante unha ligazón pública",
    "{email} downloaded {file}" : "{email} descargou {file}",
    "Shared with group {group}" : "Compartido co grupo {group}",
    "Removed share for group {group}" : "Retirar o compartido para o grupo {group}",
    "{actor} shared with group {group}" : "{actor} compartiu co grupo {group}",
    "{actor} removed share for group {group}" : "{actor} retirou o compartido para o grupo {group}",
    "You shared {file} with group {group}" : "Vostede compartiu {file} co grupo {group}",
    "You removed group {group} from {file}" : "Vostede retirou o grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} compartiu {file} co grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} retirou o grupo {group} de {file}",
    "Shared as public link" : "Compartido como ligazón pública",
    "Removed public link" : "Retirada a ligazón pública",
    "Public link expired" : "A ligazón pública caducou",
    "{actor} shared as public link" : "{actor} compartiu como ligazón pública",
    "{actor} removed public link" : "{actor} retirou a ligazón pública",
    "Public link of {actor} expired" : "A ligazón pública de {actor} caducou",
    "You shared {file} as public link" : "Vostede compartiu {file} como ligazón pública",
    "You removed public link for {file}" : "Vostede retirou a ligazón pública de {file}",
    "Public link expired for {file}" : "A ligazón pública para {file} caducou",
    "{actor} shared {file} as public link" : "{actor} compartiu {file} como ligazón pública",
    "{actor} removed public link for {file}" : "{actor} retirou a ligazón pública para {file}",
    "Public link of {actor} for {file} expired" : "A ligazón pública de {actor} para {file} caducou",
    "{user} accepted the remote share" : "{user} aceptou a compartición remota",
    "{user} declined the remote share" : "{user} declinou a compartición remota",
    "You received a new remote share {file} from {user}" : "Recibiu unha nova compartición remota {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceptou a compartición remotade {file}",
    "{user} declined the remote share of {file}" : "{user} declinou a compartición remota de {file}",
    "{user} unshared {file} from you" : "{user} deixou de compartir {file} con vostede",
    "Shared with {user}" : "Compartido con {user}",
    "Removed share for {user}" : "Retirar o compartido para {user}",
    "{actor} shared with {user}" : "{actor} compartiu con {user}",
    "{actor} removed share for {user}" : "{actor} retirou o compartido para {user}",
    "Shared by {actor}" : "Compartido por {actor}",
    "{actor} removed share" : "{actor} retirou o compartido",
    "You shared {file} with {user}" : "Vostede compartiu {file} con  {user}",
    "You removed {user} from {file}" : "Vostede retirou a {user} de {file}",
    "{actor} shared {file} with {user}" : "{actor} compartiu {file} con {user}",
    "{actor} removed {user} from {file}" : "{actor} retirou a {user} de {file}",
    "{actor} shared {file} with you" : "{actor} compartiu {file} con vostede",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Foi  <strong>descargado</strong> un ficheiro ou cartafol compartido por correo ou ligazón pública",
    "A file or folder was shared from <strong>another server</strong>" : "Compartiuse un ficheiro ou cartafol desde <strong>outro servidor</strong>",
    "A file or folder has been <strong>shared</strong>" : "<strong>Compartiuse</strong> un ficheiro ou cartafol",
    "Wrong share ID, share doesn't exist" : "O ID do recurso compartido non é correcto, o recurso compartido non existe",
    "could not delete share" : "non foi posíbel eliminar o recurso compartido",
    "Could not delete share" : "Non foi posíbel eliminar o recurso compartido",
    "Please specify a file or folder path" : "Especifique a ruta dun ficheiro ou cartafol",
    "Wrong path, file/folder doesn't exist" : "Ruta incorrecta, o ficheiro/cartafol non existe",
    "Could not create share" : "Non foi posíbel crear o recurso compartido",
    "invalid permissions" : "permisos incorrectos",
    "Please specify a valid user" : "Especifique un usuario correcto",
    "Group sharing is disabled by the administrator" : "A opción de compartir en grupo foi desactivada polo administrador",
    "Please specify a valid group" : "Especifique un grupo correcto",
    "Public link sharing is disabled by the administrator" : "Compartir por ligazón pública foi desactivado polo administrador",
    "Public upload disabled by the administrator" : "O envío público foi desactivado polo administrador",
    "Public upload is only possible for publicly shared folders" : "O envío público só é posíbel para aos cartafoles públicos compartidos",
    "Invalid date, date format must be YYYY-MM-DD" : "Data incorrecta, o formato da date debe ser AAAA-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "Vostede non pode compartir para un Circulo se a aplicación non esta activada",
    "Please specify a valid circle" : "Especifique un circulo correcto",
    "Unknown share type" : "Tipo descoñecido de recurso compartido",
    "Not a directory" : "Non é un directorio",
    "Could not lock path" : "Non foi posíbel bloquear a ruta",
    "Wrong or no update parameter given" : "Parámetro incorrecto ou non actualizado",
    "Can't change permissions for public share links" : "Non é posíbel cambiar os permisos das ligazóns de recursos compartidos públicos",
    "Cannot increase permissions" : "Non é posíbel aumentar os permisos",
    "Direct link" : "Ligazón directa",
    "Add to your Nextcloud" : "Engadir ao seu Nextcloud",
    "Share API is disabled" : "A API de compartición foi desactivada",
    "File sharing" : "Compartición de ficheiros",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Name" : "Nome",
    "Share time" : "Compartir o tempo",
    "Expiration date" : "Data de caducidade",
    "Sorry, this link doesn’t seem to work anymore." : "Semella que esta ligazón non funciona.",
    "Reasons might be:" : "As razóns poderían ser:",
    "the item was removed" : "o elemento foi retirado",
    "the link expired" : "a ligazón caducou",
    "sharing is disabled" : "foi desactivada a compartición",
    "For more info, please ask the person who sent this link." : "Para obter máis información, pregúntelle á persoa que lle enviou a ligazón.",
    "Download %s" : "Descargar %s",
    "Upload files to %s" : "Enviar ficheiros a %s",
    "Select or drop files" : "Seleccione ou arrastre e solte ficheiros",
    "Uploading files…" : "Enviando ficheiros…",
    "Uploaded files:" : "Ficheiros enviados:",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Fallou a compartición de %s, xa que a infraestrutura non permite accións do tipo %s",
    "This share is password-protected" : "Esta compartición está protexida con contrasinal",
    "The password is wrong. Try again." : "O contrasinal é incorrecto. Ténteo de novo.",
    "Password" : "Contrasinal"
},
"nplurals=2; plural=(n != 1);");
